@@ -1,6 +1,6 @@
 package Catalyst::Exception::Interface;
 
-use Moose::Role;
+use MooseX::Role::WithOverloading;
 use namespace::clean -except => 'meta';
 
 use overload
@@ -27,8 +27,8 @@ Catalyst::Exception::Interface - Role defining the interface for Catalyst except
 
    # This comprises the required interface.
    sub as_string { 'the exception text for stringification' }
-   sub throw { shift; die @_ }
-   sub rethrow { shift; die @_ }
+   sub die { shift; die @_ }
+   sub die { shift; die @_ }
 
 =head1 DESCRIPTION
 
@@ -38,6 +38,9 @@ It ensures that all exceptions follow the expected interface,
 and adds overloading for stringification when composed onto a
 class.
 
+Note that if you compose this role onto another role, that role
+must use L<MooseX::Role::WithOverloading>.
+
 =head1 REQUIRED METHODS
 
 =head2 as_string
