@@ -1,7 +1,7 @@
 package TestApp::Controller::Priorities::re_vs_index;
 
 use strict;
-use base 'Catalyst::Base';
+use base 'Catalyst::Controller';
 
 sub index :Private { $_[1]->res->body( 'index' ) }
 
